pub enum L1BridgeCalls {
l2BridgeAddress(l2BridgeAddressCall),
}Expand description
Container for all the L1Bridge function calls.
Variants
l2BridgeAddress(l2BridgeAddressCall)
Implementations
Sourceimpl L1BridgeCalls
impl L1BridgeCalls
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.